powered by
Identifies sequences of codes that follow each other from time domain signal analysis, and optionally plots them as a Sankey diagram.
followingCodes( tdsc, depth = 2, min_code = 0, max_code = 10, colourCode = 1, plot = F, ... )
A TDSC object
The length of the sequence of codes to search for
The minimum value of code to include in sequence
The maximum value of code to include in sequence
If plot is alluvial, colour all codes following this code
If "alluvial" plots the found sequences in a river plot
Arguments to pass to the plotting function
if (FALSE) { library(tuneR) wave <- readWave(system.file("extdata", "1.wav", package="tdsc")) t <- tdsc(wave) followingCodes(t) followingCodes(t, colourCode=2,plot="alluvial") }
Run the code above in your browser using DataLab